==> stylish-haskell-0.14.4.0-30-x86_64.pkg.tar.zst: usr/share/haskell/register/stylish-haskell.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 stylish-haskell
version:              0.14.4.0
visibility:           public
id:                   stylish-haskell-0.14.4.0-1EERcSAcHWnANC9xXvYONp
key:                  stylish-haskell-0.14.4.0-1EERcSAcHWnANC9xXvYONp
license:              BSD-3-Clause
copyright:            2012 Jasper Van der Jeugt
maintainer:           Jasper Van der Jeugt <m@jaspervdj.be>
author:               Jasper Van der Jeugt <m@jaspervdj.be>
homepage:             https://github.com/haskell/stylish-haskell
synopsis:             Haskell code prettifier
description:
    A Haskell code prettifier. For more information, see:

    <https://github.com/haskell/stylish-haskell/blob/master/README.markdown>

category:             Language
abi:                  8a3556009e6493637cb618f408457db8
exposed:              True
exposed-modules:
    Language.Haskell.Stylish Language.Haskell.Stylish.Config
    Language.Haskell.Stylish.GHC Language.Haskell.Stylish.Module
    Language.Haskell.Stylish.Parse Language.Haskell.Stylish.Printer
    Language.Haskell.Stylish.Step Language.Haskell.Stylish.Step.Data
    Language.Haskell.Stylish.Step.Imports
    Language.Haskell.Stylish.Step.LanguagePragmas
    Language.Haskell.Stylish.Step.ModuleHeader
    Language.Haskell.Stylish.Step.SimpleAlign
    Language.Haskell.Stylish.Step.Squash
    Language.Haskell.Stylish.Step.Tabs
    Language.Haskell.Stylish.Step.TrailingWhitespace
    Language.Haskell.Stylish.Step.UnicodeSyntax

hidden-modules:
    Language.Haskell.Stylish.Align Language.Haskell.Stylish.Block
    Language.Haskell.Stylish.Comments
    Language.Haskell.Stylish.Config.Cabal
    Language.Haskell.Stylish.Config.Internal
    Language.Haskell.Stylish.Editor Language.Haskell.Stylish.Ordering
    Language.Haskell.Stylish.Util Language.Haskell.Stylish.Verbose
    Paths_stylish_haskell

import-dirs:          /usr/lib/ghc-9.4.8/site-local/stylish-haskell-0.14.4.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/stylish-haskell-0.14.4.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/stylish-haskell-0.14.4.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/stylish-haskell
hs-libraries:         HSstylish-haskell-0.14.4.0-1EERcSAcHWnANC9xXvYONp
depends:
    Cabal-3.8.1.0 HsYAML-0.2.1.3-4fFVfTNetSJ4XmiJ9xDaGK
    HsYAML-aeson-0.2.0.1-7ezRFRUfx0iBZ9SQR1q88P
    aeson-2.1.2.1-LS8mizUYnpf1U9zpV4sjcf base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7 directory-1.3.7.1
    file-embed-0.0.15.0-7OnjuFj6gBM9fqBKJCVXdU filepath-1.4.2.2
    ghc-9.4.8 ghc-boot-9.4.8 ghc-boot-th-9.4.8
    ghc-lib-parser-ex-9.4.0.0-LkvSMXj5jQCBlVWrI4flpT mtl-2.2.2
    regex-tdfa-1.3.2.4-AAuM6ZM4tbzHRXDs6OdINo
    syb-0.7.2.4-HJAbU0lurQkHN7nU4EHwhb text-2.0.2

haddock-interfaces:   /usr/share/doc/stylish-haskell/html/stylish-haskell.haddock
haddock-html:         /usr/share/doc/stylish-haskell/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> stylish-haskell-0.14.4.0-35-x86_64.pkg.tar.zst: usr/share/haskell/register/stylish-haskell.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 stylish-haskell
version:              0.14.4.0
visibility:           public
id:                   stylish-haskell-0.14.4.0-3Gvr5IWFHu04vFjHayh1V0
key:                  stylish-haskell-0.14.4.0-3Gvr5IWFHu04vFjHayh1V0
license:              BSD-3-Clause
copyright:            2012 Jasper Van der Jeugt
maintainer:           Jasper Van der Jeugt <m@jaspervdj.be>
author:               Jasper Van der Jeugt <m@jaspervdj.be>
homepage:             https://github.com/haskell/stylish-haskell
synopsis:             Haskell code prettifier
description:
    A Haskell code prettifier. For more information, see:

    <https://github.com/haskell/stylish-haskell/blob/master/README.markdown>

category:             Language
abi:                  31bcf089d5748605771b0a01c40acdb4
exposed:              True
exposed-modules:
    Language.Haskell.Stylish Language.Haskell.Stylish.Config
    Language.Haskell.Stylish.GHC Language.Haskell.Stylish.Module
    Language.Haskell.Stylish.Parse Language.Haskell.Stylish.Printer
    Language.Haskell.Stylish.Step Language.Haskell.Stylish.Step.Data
    Language.Haskell.Stylish.Step.Imports
    Language.Haskell.Stylish.Step.LanguagePragmas
    Language.Haskell.Stylish.Step.ModuleHeader
    Language.Haskell.Stylish.Step.SimpleAlign
    Language.Haskell.Stylish.Step.Squash
    Language.Haskell.Stylish.Step.Tabs
    Language.Haskell.Stylish.Step.TrailingWhitespace
    Language.Haskell.Stylish.Step.UnicodeSyntax

hidden-modules:
    Language.Haskell.Stylish.Align Language.Haskell.Stylish.Block
    Language.Haskell.Stylish.Comments
    Language.Haskell.Stylish.Config.Cabal
    Language.Haskell.Stylish.Config.Internal
    Language.Haskell.Stylish.Editor Language.Haskell.Stylish.Ordering
    Language.Haskell.Stylish.Util Language.Haskell.Stylish.Verbose
    Paths_stylish_haskell

import-dirs:          /usr/lib/ghc-9.4.8/site-local/stylish-haskell-0.14.4.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/stylish-haskell-0.14.4.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/stylish-haskell-0.14.4.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/stylish-haskell
hs-libraries:         HSstylish-haskell-0.14.4.0-3Gvr5IWFHu04vFjHayh1V0
depends:
    Cabal-3.8.1.0 HsYAML-0.2.1.3-4fFVfTNetSJ4XmiJ9xDaGK
    HsYAML-aeson-0.2.0.1-AlZZB07be8yJ27y5HLnHo1
    aeson-2.1.2.1-H9spCVKCz3aBZuysSTfrjv base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7 directory-1.3.7.1
    file-embed-0.0.16.0-FS79AECsQN660bIXAMLGHY filepath-1.4.2.2
    ghc-9.4.8 ghc-boot-9.4.8 ghc-boot-th-9.4.8
    ghc-lib-parser-ex-9.4.0.0-EzokEiK63TG8xTYS3mth89 mtl-2.2.2
    regex-tdfa-1.3.2.4-3uSstSTaLA6FCpVbUR8EKw
    syb-0.7.2.4-HJAbU0lurQkHN7nU4EHwhb text-2.0.2

haddock-interfaces:   /usr/share/doc/stylish-haskell/html/stylish-haskell.haddock
haddock-html:         /usr/share/doc/stylish-haskell/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
